@@ -64,9 +64,9 @@ use warnings;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-28'; # DATE
+our $DATE = '2024-01-06'; # DATE
 our $DIST = 'TableData-Perl-CPAN-Release-Dynamic'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 with 'TableDataRole::Perl::CPAN::Release::Dynamic';
 
@@ -85,7 +85,14 @@ TableDataRole::Perl::CPAN::Release::Dynamic - CPAN releases
 
 =head1 VERSION
 
-This document describes version 0.002 of TableDataRole::Perl::CPAN::Release::Dynamic (from Perl distribution TableData-Perl-CPAN-Release-Dynamic), released on 2023-12-28.
+This document describes version 0.003 of TableDataRole::Perl::CPAN::Release::Dynamic (from Perl distribution TableData-Perl-CPAN-Release-Dynamic), released on 2024-01-06.
+
+=head1 SYNOPSIS
+
+From the command-line (requires the CLI L<tabledata> from L<App::tabledata>):
+
+ # Show 2023-12-28 releases:
+ % tabledata Perl::CPAN::Release::Dynamic=from_date,2023-12-28,to_date,2023-12-28
 
 =head1 TABLEDATA NOTES
 
@@ -127,7 +134,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
